# EigenAPI-Client

eigenapi-client is a python wrapper of [EigenAPI](https://eigenapi.io/).


Github repository of this project is located at https://github.com/eigenphi/eigenapi-client. 

The repo maybe not open sourced currently, and we are planning to open it.

### Install eigenapi-client

You can install eigenapi-client by:

```shell
pip install eigenapi-client
```

We published this python lib to pypi. 

You can find it at [Pypi Page](https://pypi.org/project/eigenapi-client/)


### Document of EigenAPI

API Document can be found [here](https://eigenphi-1.gitbook.io/eigenapi-user-guide/introduction/introduction)

